@@ -2,7 +2,7 @@ package sapnwrfc;
 use strict;
 
 use vars qw($VERSION $AUTOLOAD $DEBUG);
-$VERSION = '0.06';
+$VERSION = '0.08';
 
 use SAPNW::Base;
 $SAPNW::Base::DEBUG = 0;
@@ -113,4 +113,68 @@ perl(1), ABAP(101).
 
 =cut
 
+
+  # Export useful tools
+  my @export_ok = qw(
+	 debug
+   RFCIMPORT
+   RFCEXPORT
+   RFCCHANGING
+   RFCTABLES
+   RFCTYPE_CHAR
+   RFCTYPE_DATE
+   RFCTYPE_BCD
+   RFCTYPE_TIME
+   RFCTYPE_BYTE
+   RFCTYPE_TABLE
+   RFCTYPE_NUM
+   RFCTYPE_FLOAT
+   RFCTYPE_INT
+   RFCTYPE_INT2
+   RFCTYPE_INT1
+   RFCTYPE_NULL
+   RFCTYPE_STRUCTURE
+   RFCTYPE_DECF16
+   RFCTYPE_DECF34
+   RFCTYPE_XMLDATA
+   RFCTYPE_STRING
+   RFCTYPE_XSTRING
+   RFCTYPE_EXCEPTION
+   RFC_OK
+   RFC_COMMUNICATION_FAILURE
+   RFC_LOGON_FAILURE
+   RFC_ABAP_RUNTIME_FAILURE
+   RFC_ABAP_MESSAGE
+   RFC_ABAP_EXCEPTION
+   RFC_CLOSED
+   RFC_CANCELED
+   RFC_TIMEOUT
+   RFC_MEMORY_INSUFFICIENT
+   RFC_VERSION_MISMATCH
+   RFC_INVALID_PROTOCOL
+   RFC_SERIALIZATION_FAILURE
+   RFC_INVALID_HANDLE
+   RFC_RETRY
+   RFC_EXTERNAL_FAILURE
+   RFC_EXECUTED
+   RFC_NOT_FOUND
+   RFC_NOT_SUPPORTED
+   RFC_ILLEGAL_STATE
+   RFC_INVALID_PARAMETER
+   RFC_CODEPAGE_CONVERSION_FAILURE
+   RFC_CONVERSION_FAILURE
+   RFC_BUFFER_TOO_SMALL
+   RFC_TABLE_MOVE_BOF
+   RFC_TABLE_MOVE_EOF
+	);
+
+  sub import {
+    my ( $caller ) = caller;
+    no strict 'refs';
+    foreach my $sub ( @export_ok ){
+      *{"${caller}::${sub}"} = \&{$sub};
+    }
+  }
+
+
 1;
